import sys
sys.path.append('.')
import lvgl as lv
import lv_utils
import time
import uctypes
import struct
import machine

import gc

class WIDGETS(object):
    def __init__(self,LCD=None,TSC=None,IMU=None,RTC=None,BEEP_pwm=None):
        # Init parameter
        self.LCD = LCD
        self.TSC = TSC
        self.IMU = IMU 
        self.RTC = RTC
        self.BEEP_pwm = BEEP_pwm
        
        # Init Timer
        self.rtc_update_timer = machine.Timer(-1)
        self.imu_data_update_timer = machine.Timer(-1)
        self.rtc_update_timer.init(period=300, mode=machine.Timer.PERIODIC, callback=self.rtc_data_update_timer_cb)
        self.imu_data_update_timer.init(period=500, mode=machine.Timer.PERIODIC, callback=self.imu_data_update_timer_cb)

        # Style Config
        style_slider = lv.style_t()
        style_slider.init()
        style_slider.set_bg_color(lv.palette_main(lv.PALETTE.ORANGE))
        style_slider.set_border_color(lv.palette_darken(lv.PALETTE.ORANGE, 3))

        style_indic = lv.style_t()
        style_indic.init()
        style_indic.set_bg_color(lv.palette_lighten(lv.PALETTE.DEEP_ORANGE, 3))
        style_indic.set_bg_grad_color(lv.palette_main(lv.PALETTE.DEEP_ORANGE))
        style_indic.set_bg_grad_dir(lv.GRAD_DIR.HOR)

        style_indic_pr = lv.style_t()
        style_indic_pr.init()
        style_indic_pr.set_shadow_color(lv.palette_main(lv.PALETTE.DEEP_ORANGE))
        style_indic_pr.set_shadow_width(10)
        style_indic_pr.set_shadow_spread(3)

        style_sw = lv.style_t()
        style_sw.init()
        style_sw.set_bg_opa(lv.OPA.COVER)
        style_sw.set_bg_color(lv.palette_lighten(lv.PALETTE.RED, 1))
        style_sw.set_shadow_width(55)
        style_sw.set_shadow_color(lv.palette_main(lv.PALETTE.PINK))

        style_roller = lv.style_t()
        style_roller.init()
        style_roller.set_border_color(lv.palette_darken(lv.PALETTE.BLUE, 3))
        style_roller.set_shadow_width(55)
        style_roller.set_shadow_color(lv.palette_main(lv.PALETTE.BLUE_GREY))

        style_imu_table = lv.style_t()
        style_imu_table.init()
        style_imu_table.set_border_width(1)
        style_imu_table.set_text_font(lv.font_montserrat_16)

        style_rtc_table = lv.style_t()
        style_rtc_table.init()
        style_rtc_table.set_border_width(1)
        style_rtc_table.set_text_font(lv.font_montserrat_16)

        # Create tileview
        self.scr = lv.obj()
        self.tv = lv.tileview(self.scr)
        self.tv.set_scrollbar_mode(lv.SCROLLBAR_MODE.OFF)

        # Tile1: Just a pic
        self.tile1 = self.tv.add_tile(0, 0, lv.DIR.BOTTOM)

        waveshare_logo_data = (
            b'\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF'
            b'\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\xDF\xE7\xDF\xD7\xDF\xCF\xFF\xCF\xDF\xCF\xFF\xCF\xDF\xCF\xFF\xCF\xFF\xCF\xFF\xCF\xFF\xCF\xFF\xCF\xFF\xCF\xDF\xCF\xDF\xD7\xFF\xD7\xDF\xCF\xBF\xD7\xFF\xDF\xFF\xDF\xFF\xE7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\xFF\xDF\xFF\xDF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\xFF\xEF\xFF\xEF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xEF\xFF\xE7\xFF\xE7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF'
            b'\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xD7\x33\x54\xD3\x33\x14\x34\x14\x34\x14\x34\xF4\x33\x14\x34\x14\x34\x14\x34\x14\x34\x14\x34\x14\x34\x14\x34\xF4\x33\xF4\x33\x14\x34\xF4\x33\xF4\x33\x15\x3C\x56\x44\xD7\x5C\xFA\x95\xFD\xC6\xFF\xEF\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xDF\x74\x64\x78\x85\xFD\xC6\xFF\xF7\xFF\xFF\xFF\xF7\x5B\xAE\xB1\x3B\x95\x5C\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xF5\x7C\x95\x5C\xB9\x85\xDF\xE7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x7F\xD7\xBD\xAE\x9C\xA6\xDD\xAE\xDD\xAE\xDD\xA6\xDD\xA6\xDD\xAE\xBD\xAE\xBD\xAE\xBE\xAE\xBE\xAE\xBE\xA6\xBD\xAE\xBD\xAE\xBD\xB6\xBD\xAE\xBD\xAE\xBD\xAE\xBD\xB6\xDC\xC6\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xBF\xE7\x75\x5C\x55\x4C\x33\x54\x1E\xBF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xEF\xFF\xEF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xBF\x14\x3C\xD4\x1B\xF5\x13\xF5\x13\xF5\x13\xF5\x13\xF5\x13\xF5\x13\xF5\x13\xF5\x13\xF5\x13\xF5\x13\xF6\x13\xF5\x13\xF6\x13\xF6\x13\xD5\x13\xF6\x1B\xF5\x13\xD4\x0B\xF4\x13\x93\x13\xB3\x23\x76\x3C\x3C\x86\xFF\xDF\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\x39\x65\x93\x1B\x52\x23\x55\x54\xFF\xE7\xFF\xF7\xFF\xF7\x3B\x9E\x51\x1B\x96\x44\xFF\xE7\xFF\xF7\xFF\xF7\xFF\xEF\xFF\xDF\x33\x4C\x72\x1B\xB2\x33\xFF\xE7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDA\x8D\x52\x1B\xB4\x1B\xB4\x13\xB3\x0B\xB3\x13\xD4\x13\xB4\x13\xB4\x13\xB4\x13\xB4\x13\xB4\x1B\xB4\x13\xB4\x13\xB3\x1B\xB4\x1B\x94\x13\xB5\x13\xB5\x13\x73\x1B\xF3\x4B\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x5F\xD7\xB4\x2B\xB4\x1B\x72\x23\xDD\xAE\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\x5B\xAE\xDA\x8D\x3C\x8E\x3C\x86\x3C\x7E\x1B\x7E\x5C\x86\x3C\x86\x1C\x86\x3C\x86\x1C\x7E\x3C\x7E\x3C\x86\x3D\x86\x1D\x86\x3D\x86\x1C\x86\xBA\x7D\x9F\xCF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xBF\x55\x34\xF6\x13\x17\x0C\x17\x0C\x37\x0C\x37\x0C\x37\x0C\x37\x0C\x37\x0C\x36\x0C\x36\x0C\x37\x0C\x37\x0C\x17\x14\x17\x14\x17\x0C\x58\x14\x17\x0C\x37\x0C\x57\x0C\x36\x04\x57\x14\x16\x14\xD5\x13\xB3\x13\x35\x44\x7C\x9E\xFF\xEF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\x1B\x8E\xB4\x1B\xB5\x13\xD4\x2B\x9F\xBF\x1C\x96\x34\x5C\x5F\xCF\x9D\xA6\x72\x13\xD7\x3C\xFF\xD7\xF5\x7C\x95\x6C\xBF\xCF\xFF\xCF\xB3\x2B\xD4\x1B\xB7\x4C\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x1B\x8E\x73\x23\xF5\x1B\x36\x1C\x36\x1C\x15\x14\xD5\x13\x16\x1C\x37\x1C\x37\x14\x16\x0C\x16\x0C\x16\x14\x16\x1C\x15\x24\xF5\x1B\xF6\x1B\x37\x1C\xF6\x13\xD5\x1B\x55\x4C\xFF\xE7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xBF\xCF\xD5\x1B\xF7\x13\xB4\x1B\x1F\xA7\xFF\xEF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\x54\x64\x51\x23\x93\x1B\xB4\x13\xB4\x13\xD4\x1B\x93\x13\x93\x1B\x94\x23\x94\x1B\x94\x13\xD4\x23\x93\x13\xB4\x1B\xB4\x13\xD5\x13\xB4\x13\x93\x1B\xD2\x3B\x5A\xAE\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xC7\x55\x3C\xF6\x13\x37\x14\x17\x0C\x37\x14\x37\x14\x37\x14\x17\x0C\x37\x0C\x36\x0C\x36\x0C\x37\x0C\x17\x0C\x17\x14\x17\x14\x37\x0C\x37\x0C\x37\x0C\x17\x0C\x17\x0C\x17\x0C\xF6\x0B\x16\x14\x17\x1C\x17\x1C\x95\x13\x94\x1B\x19\x65\xFF\xD7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF'
            b'\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\x5D\x8E\x94\x1B\xD5\x13\xB3\x1B\x9C\xA6\xFF\xE7\x19\x65\xF2\x22\xBE\xAE\xDE\xAE\x72\x13\x97\x34\xFF\xCF\x12\x4C\x0F\x2B\xBF\xB7\x7F\xAF\x93\x23\x93\x1B\x7A\x6D\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xE7\xFF\xCF\xFF\xD7\xDF\xC7\xFF\xC7\xFF\xC7\xFF\xC7\xFF\xC7\xFF\xB7\x98\x34\x16\x0C\xF6\x0B\x3F\x97\xFF\xC7\xFF\xCF\xFF\xCF\xFF\xC7\xFF\xC7\xFF\xC7\xFF\xC7\xFF\xD7\xFF\xEF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\x7F\xD7\x5F\xBF\x5F\xBF\x5F\xBF\x7F\xBF\x3F\xB7\x7F\xB7\x9F\xBF\xDF\x96\xF6\x1B\x17\x14\xD5\x13\x9F\x76\xBF\xB7\x5F\xB7\x7F\xBF\x5F\xBF\x5F\xB7\x5F\xB7\x7F\xBF\x7F\xCF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xEF\x54\x5C\x52\x1B\x94\x13\xB5\x13\xB5\x13\xB4\x13\xB4\x1B\x94\x1B\x94\x1B\x94\x13\xB5\x1B\x94\x13\xB4\x1B\xF5\x13\x16\x14\x17\x14\x16\x14\x16\x1C\x72\x1B\xB5\x6C\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xC7\x35\x3C\xF6\x13\x17\x0C\x17\x0C\x17\x0C\x17\x14\x17\x14\x17\x0C\x17\x0C\x16\x0C\x16\x0C\x17\x0C\x17\x0C\x17\x0C\x17\x0C\x16\x0C\x36\x0C\x16\x0C\x37\x14\x17\x14\x17\x14\xF5\x13\x56\x24\x16\x14\xF7\x13\x17\x14\xF6\x13\xD5\x1B\x15\x3C\x9F\xCF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xD9\x95\x93\x23\xF5\x1B\xB3\x13\x3C\x86\xFF\xE7\xFF\xE7\x1A\x5D\x74\x1B\xFF\xAE\xBE\xA6\x93\x13\xF8\x3C\xFF\xC7\x33\x4C\x91\x2B\xFF\xB7\xDF\x8E\x93\x1B\x94\x1B\x7E\x86\xFF\xDF\xFF\xEF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xDF\xEF\x58\x95\x59\x7D\x79\x7D\x58\x7D\xB9\x8D\x79\x7D\x9A\x7D\x79\x7D\x7A\x7D\xBB\x6D\x15\x24\xF6\x0B\xF6\x13\x19\x5D\x9A\x7D\x79\x7D\x99\x85\x99\x85\x99\x7D\xB9\x7D\xB9\x7D\x79\x75\x17\x75\x9C\xBE\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xF6\x74\x71\x2B\xB4\x2B\x93\x2B\xD4\x2B\xD4\x2B\xD4\x23\xD4\x23\xD5\x23\xD6\x13\x38\x14\x17\x0C\xF5\x13\xD3\x1B\xD3\x23\xD4\x2B\xB4\x2B\xD4\x23\xD4\x2B\x72\x23\x54\x54\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\xFA\x9D\x79\x75\x7A\x6D\x9B\x6D\x9B\x6D\x9B\x6D\x9A\x6D\x7A\x6D\x9B\x6D\xBB\x6D\xBB\x65\xDC\x65\xFD\x5D\x77\x24\x16\x14\xF6\x0B\xF6\x13\x93\x1B\x38\x65\xFF\xDF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xC7\x34\x3C\xF6\x13\x37\x0C\x17\x0C\x37\x0C\x17\x0C\x17\x0C\x37\x0C\x37\x0C\x36\x0C\x36\x0C\x37\x0C\x37\x0C\x37\x0C\x17\x0C\x37\x14\x36\x0C\x36\x0C\x16\x0C\x17\x14\xB4\x13\xDA\x6D\x1B\x6E\xD4\x0B\x37\x0C\x37\x1C\xF6\x13\x17\x14\xD5\x13\x35\x3C\xDF\xCF\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\x74\x64\x73\x1B\x93\x13\xFB\x7D\xFF\xCF\x3F\xBF\xFF\xDF\x9C\x65\x53\x1B\x3F\xAF\xFF\xA6\x74\x13\xB9\x3C\xFF\xCF\x76\x4C\x71\x2B\xDF\xB7\xBB\x5D\xD4\x1B\xF5\x13\xB8\x34\x19\x45\x19\x55\xF9\x54\x97\x5C\x1E\xC7\xFF\xEF\xFF\xDF\xD2\x43\x72\x1B\x93\x1B\x72\x1B\x32\x1B\x52\x23\x31\x1B\x31\x23\x52\x23\x32\x13\x16\x1C\x17\x14\x17\x1C\x93\x13\x72\x1B\x52\x1B\x31\x1B\x32\x1B\x52\x1B\x51\x13\x93\x1B\xD5\x1B\x73\x13\x99\x85\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xEF\x37\x75\x93\x1B\x16\x14\xD5\x13\xD5\x13\xD5\x0B\xD5\x0B\xD5\x13\xD5\x13\x17\x1C\x17\x14\x37\x0C\xF6\x0B\xD5\x13\xD5\x13\xB4\x13\xB5\x13\xB5\x13\xF6\x1B\xF5\x1B\xB6\x4C\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xEF\xFF\xF7\xFF\xF7\xFF\xEF\xFF\xEF\xFF\xEF\xFF\xE7\xFF\xEF\xFF\xDF\xFF\xC7\x9B\x55\xF7\x13\xF7\x13\xB5\x0B\xB3\x1B\x1B\x8E\xFF\xEF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xC7\x34\x3C\xF6\x13\x38\x0C\x17\x0C\x37\x0C\x17\x0C\x17\x0C\x37\x0C\x37\x0C\x36\x0C\x36\x0C\x37\x0C\x37\x0C\x37\x0C\x17\x0C\x17\x0C\xF6\x0B\x36\x0C\x37\x14\x94\x13\x18\x55\xFF\xD7\x3B\x86\xD4\x0B\x37\x0C\xF6\x0B\x37\x14\x37\x0C\x16\x0C\xD4\x13\x76\x44\xFF\xE7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xBF\xD7\xB2\x33\xFC\x75\xFF\xD7\xF6\x6C\x50\x2B\xB6\x4C\x97\x34\xB4\x1B\x3A\x5D\x19\x5D\xB5\x13\x57\x24\xBC\x65\xF5\x33\x93\x2B\x7F\xA7\xB8\x34\xF5\x13\x15\x1C\xD4\x13\xD5\x0B\xB5\x0B\xB6\x13\x33\x1B\x7C\xAE\xFF\xEF\xFF\xD7\x34\x44\xD4\x13\x57\x24\x3E\x6E\x7F\x7E\x7F\x7E\x3E\x7E\x5E\x7E\x5E\x7E\x3D\x6E\x36\x24\xD6\x0B\xF6\x13\x7A\x55\x5D\x76\x7F\x7E\x9F\x7E\x7F\x7E\x5E\x76\x5D\x76\x39\x4D\xD6\x0B\xB5\x13\xBA\x7D\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xEF\x17\x6D\xB5\x13\x37\x14'
            b'\x36\x24\xB8\x3C\xB8\x3C\xD8\x3C\xB6\x3C\x97\x34\xF6\x13\x17\x14\xF6\x0B\x98\x2C\xD8\x3C\x97\x44\xB7\x44\xB8\x3C\x78\x2C\xF6\x13\xD5\x0B\xB7\x44\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xEF\x3B\x96\xF3\x2B\xB4\x1B\xF6\x1B\x94\x13\x56\x3C\xFE\xA6\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xC7\x34\x3C\xF6\x13\x38\x0C\x17\x0C\x17\x0C\x17\x14\x17\x14\x17\x0C\x17\x0C\x16\x14\x36\x14\x37\x0C\x37\x0C\x17\x0C\x17\x14\x16\x14\x57\x1C\x17\x14\x94\x13\xB7\x54\xFF\xDF\xFF\xE7\xFA\x85\xB4\x13\x38\x0C\x18\x0C\x17\x0C\x57\x0C\x16\x0C\x17\x14\xB4\x1B\x99\x7D\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x7F\xD7\xFF\xE7\x1F\xA7\x93\x23\xB3\x1B\x76\x34\xB8\x34\xB4\x13\x93\x13\xB4\x13\xD4\x0B\xF5\x0B\x94\x0B\xB5\x1B\xB5\x23\x3F\x76\x57\x1C\xF5\x13\x35\x2C\xB7\x44\x97\x34\xD5\x1B\xF6\x1B\xF5\x33\xDD\xBE\xFF\xF7\xFF\xDF\x34\x44\xB4\x13\x1A\x3D\xFF\xB7\xBE\x8E\x9F\x86\xDF\x8E\x7F\x86\xDF\x96\xFF\xC7\xD7\x44\xD5\x0B\xD5\x13\xDF\xAF\x9F\xB7\x9F\x8E\xDF\x8E\xDF\x8E\xBF\x96\xDF\xBF\xFF\x96\xB5\x13\xB4\x13\xDA\x85\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xEF\x38\x6D\xD5\x13\xB4\x0B\x9A\x6D\xFF\xDF\xFF\xE7\xFF\xE7\xFF\xEF\xBF\xC7\xF6\x23\xF6\x13\xD5\x1B\x1F\x97\xFF\xDF\xFF\xEF\xFF\xEF\xFF\xE7\x7E\x86\xD5\x1B\xB4\x03\xF8\x4C\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xDE\xB6\x55\x44\xB4\x1B\xF5\x13\xD5\x13\x73\x1B\x59\x6D\xBF\xD7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xC7\x35\x3C\xF6\x13\x38\x0C\x17\x0C\x38\x0C\x17\x0C\x17\x0C\x17\x0C\x17\x0C\x17\x14\x17\x14\x37\x0C\x37\x0C\x17\x0C\x17\x14\x17\x14\x16\x14\xB5\x0B\xB8\x44\xFF\xDF\xFF\xF7\xFF\xEF\xDA\x8D\x94\x13\x18\x0C\x18\x0C\x38\x0C\x16\x0C\x57\x14\x17\x0C\xF6\x1B\x93\x23\x3F\xB7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\x57\x3C\xD5\x1B\x93\x1B\x9E\x7E\x5D\x76\x96\x34\xB7\x3C\xD7\x3C\xF8\x34\xD8\x34\xB8\x3C\xB8\x3C\xD9\x4C\xD9\x44\xD6\x0B\xD5\x13\x5D\x86\xFF\xD7\xBF\x86\xB4\x1B\xB4\x1B\xBE\x96\xFF\xF7\xFF\xFF\xFF\xDF\x34\x44\x93\x13\x19\x45\xFF\x9E\x0F\x23\x51\x23\x31\x23\x52\x23\x31\x23\x9F\xB7\xD6\x4C\xF5\x13\xF5\x13\x5F\xAF\x94\x5C\x11\x23\x32\x23\x32\x23\x10\x23\x17\x75\xDE\xA6\xB4\x1B\xB4\x1B\xBA\x8D\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xEF\x39\x6D\xB4\x13\xB4\x0B\xBA\x75\xFF\xE7\xFF\xEF\xFF\xEF\xFF\xF7\xFF\xCF\xF5\x1B\x17\x14\xB4\x13\x5F\xA7\xFF\xE7\xFF\xEF\xFF\xEF\xFF\xE7\x9F\x8E\xB4\x1B\xF5\x13\xB7\x44\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\x75\x5C\x73\x13\x17\x14\xD5\x13\x97\x3C\xFF\xA6\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xBF\x55\x3C\xF5\x13\x16\x0C\x38\x14\x18\x0C\x17\x04\x17\x0C\x37\x14\x17\x14\x17\x14\x37\x14\x17\x0C\x37\x14\xF6\x0B\x17\x14\x17\x0C\xF5\x0B\xD7\x44\xFF\xC7\xFF\xEF\xFF\xFF\xFF\xF7\xDA\x8D\x94\x13\xF7\x0B\x38\x14\x17\x0C\xF6\x0B\x37\x14\x17\x0C\x16\x14\xD4\x0B\xF7\x4C\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\x59\x75\xD5\x13\xD5\x13\x35\x44\xFF\xD7\xFF\xDF\xFF\xD7\xFF\xD7\xFF\xD7\xFF\xCF\xFF\xD7\xFF\xD7\xFF\xD7\xFF\xBF\x15\x2C\xD6\x13\xB5\x13\x1B\x8E\xFF\xDF\x3E\x7E\x73\x1B\xD3\x2B\x5F\xB7\xFF\xF7\xFF\xFF\xFF\xDF\xB3\x3B\x52\x13\x97\x3C\xFF\xC7\xDD\xAE\xDE\xA6\xDE\xA6\xFF\xAE\xDE\xA6\xFF\xD7\x96\x4C\xD5\x13\xD5\x13\x7F\xAF\x3E\xB7\x9E\x9E\xDF\xA6\x9E\x9E\x7E\x9E\x7F\xC7\x7D\x9E\x73\x1B\x52\x1B\x99\x85\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xEF\x18\x6D\xB4\x0B\x15\x0C\xD9\x3C\xFD\x75\x1C\x76\xFB\x75\x1B\x76\xDB\x65\x16\x1C\x37\x14\xD5\x13\x9B\x55\x1C\x76\xFB\x75\x1C\x7E\xFD\x75\x1A\x4D\xD5\x13\xF5\x13\xB7\x44\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\xD7\x5C\xD4\x13\xB4\x0B\x59\x6D\xFF\xDF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xC7\x55\x3C\xF4\x13\x16\x14\xD5\x13\xB5\x1B\xF5\x1B\xD5\x13\xF6\x13\x16\x14'
            b'\x37\x1C\xD5\x13\xF5\x1B\xD5\x1B\xF5\x1B\x16\x14\x17\x0C\xF5\x13\x54\x3C\x3E\xBF\xFF\xFF\xFF\xFF\xFF\xEF\xFB\x85\xB5\x1B\xF7\x13\xB5\x13\xD4\x1B\xF5\x1B\x16\x14\x16\x0C\x16\x0C\x16\x0C\xF4\x23\xFE\xBE\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\x9D\x9E\x92\x1B\x36\x14\xD5\x13\xD7\x5C\xFF\xDF\x78\x7D\xD6\x64\xF7\x64\xF7\x64\x38\x6D\xF7\x64\xF7\x64\x17\x65\x96\x44\xB4\x1B\x17\x14\xB5\x13\x39\x6D\xFF\xD7\x7B\x65\x94\x1B\xF3\x3B\xFF\xCF\xFF\xF7\xFF\xFF\xDF\xE7\x58\x7D\x18\x65\xFB\x85\x7F\xC7\x78\x85\xBA\x85\xBA\x85\x9A\x7D\xFB\x8D\xBF\xC7\x95\x54\xD5\x13\xD5\x13\x5F\xAF\x5B\x9E\xBA\x7D\xBA\x7D\xDB\x85\x99\x85\x7C\xAE\xFF\xB6\xF8\x64\x18\x65\x7B\xAE\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xEF\x39\x75\xF5\x13\x36\x0C\xD5\x13\x94\x13\x94\x1B\xB3\x1B\xB3\x1B\xB3\x0B\x16\x14\x17\x14\x17\x14\xD5\x0B\xB3\x13\x93\x1B\xB4\x1B\x94\x1B\xD5\x1B\x16\x1C\xF5\x0B\xF8\x4C\xFF\xEF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xEF\xFF\xF7\xFF\xEF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xEF\xFF\xDF\xF8\x54\xF5\x13\xD5\x13\xDB\x7D\xFF\xE7\xFF\xEF\xFF\xEF\xFF\xF7\xFF\xF7\xFF\xEF\xFF\xEF\xFF\xEF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xC7\x34\x3C\xB4\x13\x5A\x4D\x7F\xB7\x3F\xC7\x3F\xBF\x7F\xB7\x97\x34\xD5\x13\xB4\x13\x59\x5D\x7F\xBF\x7F\xBF\x5D\x7E\xD4\x13\x37\x14\xB5\x13\x14\x3C\xFF\xE7\xFF\xFF\xFF\xFF\xFF\xD7\x9A\x6D\x73\x0B\x16\x24\xFF\xA6\x7F\xC7\xDE\x96\xD3\x23\x16\x1C\x37\x0C\x57\x14\x93\x13\x78\x7D\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xEF\xFF\xA6\xB4\x23\xD5\x13\x16\x0C\xF4\x0B\xF7\x54\xFF\xCF\xD3\x2B\x72\x13\xB3\x1B\x73\x13\x74\x1B\x94\x1B\x94\x1B\xB4\x1B\x94\x1B\xF5\x13\x16\x0C\xD5\x0B\x97\x4C\xFF\xCF\xF9\x44\x73\x13\x95\x54\xFF\xE7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xEF\x9D\xB6\x10\x33\x51\x2B\x71\x2B\x51\x23\x91\x33\xDF\xC7\x95\x4C\xD4\x13\xB4\x13\x1F\xA7\x54\x5C\x11\x23\x52\x23\x51\x2B\x0F\x2B\x94\x74\xFF\xF7\xFF\xEF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xEF\x18\x6D\x74\x13\x17\x14\xD5\x1B\x94\x1B\xB4\x23\x93\x23\x92\x1B\xD4\x1B\x16\x14\x17\x14\x37\x14\xD5\x13\xB4\x1B\x93\x23\x93\x23\x93\x1B\xD5\x13\x17\x14\xD5\x0B\xD7\x44\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xDE\xBE\x99\x7D\xFA\x75\xFB\x75\x1C\x7E\xFB\x7D\xDB\x7D\xDB\x7D\xDC\x75\xFC\x75\x1D\x6E\x77\x2C\xF6\x13\xF6\x13\xF9\x44\x1D\x76\xFC\x75\xFC\x75\xDC\x7D\xDB\x7D\xFB\x75\xFB\x75\xFB\x75\xDA\x7D\xD9\x8D\xFF\xE7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xC7\x75\x44\xB4\x13\x97\x3C\xFF\xE7\xFF\xFF\xFF\xFF\xFF\xEF\x1C\x7E\xB3\x13\xB2\x1B\x3F\xAF\xFF\xEF\xFF\xF7\xFF\xD7\x35\x34\xD6\x13\xB5\x1B\xFB\x8D\xFF\xF7\xFF\xFF\xFF\xF7\x38\x75\xD3\x23\xD4\x1B\x7A\x65\xFF\xEF\xFF\xF7\xFF\xE7\x17\x65\xB4\x13\x17\x0C\x37\x0C\xD5\x13\x35\x4C\xFF\xE7\xFF\xFF\xFF\xFF\x9F\xCF\xB3\x33\xD4\x1B\x16\x14\x57\x0C\xF4\x0B\xB6\x4C\xFF\xCF\x39\x5D\xB7\x44\xD9\x3C\x1A\x45\xD9\x3C\xD9\x3C\xFA\x3C\xD9\x3C\xF9\x4C\x5A\x55\x56\x24\x15\x1C\x15\x2C\x5F\x97\x77\x2C\x93\x1B\x38\x75\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xE7\x5F\xB7\xBF\xB7\xBF\xAF\xBF\xAF\xBF\xB7\xFF\xD7\x58\x65\x76\x2C\xB7\x3C\x9F\xBF\xDF\xCF\x7F\xB7\xBF\xB7\xBF\xB7\x9F\xBF\xDF\xCF\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xEF\x18\x6D\xD6\x1B\xB6\x13\x19\x4D\xDF\x96\xBF\x9E\xDF\x9E\xDF\x9E\x7E\x7E\x17\x1C\xF7\x0B\xB5\x13\xFD\x65\xDF\x96\xDF\x9E\xDF\xA6\xFF\x9E\x9C\x55\xD5\x13\xF6\x0B\xB7\x44\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xDA\x95\x31\x23\x93\x1B\xB4\x13\xB3\x13\x93\x13\xB4\x1B\x94\x13\xB4\x1B\xB4\x1B\xD4\x13\x16\x14\x17\x14\x17\x14\xD5\x13\xB5\x13\xB4\x13\x94\x13\x94\x1B\x94\x1B\xB3\x13\xB3\x13\xB3\x13\x92\x1B\x91\x3B\xFF\xD7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xBF\x35\x3C\xB5\x13\x94\x1B\xFE\xB6\xFF\xF7\xFF\xFF\xFF\xF7\x7F\xB7\x91\x2B\x33\x44\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xEF\x9A\x7D\x94\x13\xF5\x2B\xDF\xDF\xFF\xFF\xFF\xFF\xDF\xDF\xD4\x2B\xD4\x1B\xD3\x23\x7F\xB7\xFF\xF7\xFF\xFF\xFF\xF7\x5F\xBF\xD5\x23\x17\x14\x37\x0C\x16\x14\x93\x23\x5F\xBF\xFF\xFF\xFF\xFF\xFF\xE7\xF7\x6C\x52\x1B\x15\x1C\x57\x14\xD4\x0B\xB6\x54\xFF\xE7\xFF\xDF\x7F\xBF\x9F\xAF\x7F\xA7\x9F\xAF\xBF\xAF\xBF\xA7\x7F\xAF\xFF\xDF\xFF\xDF\x9F\xB7\xF4\x2B\xF4\x1B\xDC\x55\x57\x1C\x73\x13\xFB\x95\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xDF\xBF\xC7\xFF\xCF'
            b'\xFF\xC7\xFF\xC7\xFF\xC7\xFF\xC7\xBF\xBF\xBF\xB7\xFF\xB7\xDF\xAF\xBF\xBF\xDF\xC7\xFF\xCF\xFF\xC7\xFF\xC7\xFF\xCF\xFF\xC7\xBF\xC7\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\x38\x6D\x75\x13\xB6\x13\xDB\x75\xFF\xDF\xFF\xEF\xFF\xEF\xFF\xEF\xFF\xCF\xF6\x13\x17\x0C\xB4\x1B\x7F\xA7\xFF\xE7\xFF\xEF\xFF\xEF\xFF\xDF\xFF\x96\xB4\x13\xD6\x13\xD8\x44\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xDB\x95\x32\x23\xB4\x1B\xB5\x1B\xB4\x1B\x94\x13\xD4\x1B\xB4\x13\x93\x13\xB3\x1B\xB4\x13\x16\x1C\x16\x14\x37\x14\xF5\x13\xB4\x13\xB4\x13\xB4\x13\x95\x1B\x95\x1B\xB4\x1B\xB3\x13\xB4\x13\x92\x1B\xB1\x33\xFF\xD7\xFF\xF7\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xC7\x14\x34\xF6\x1B\xB5\x1B\x79\x7D\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xE7\xF2\x4B\x98\x85\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\x1F\xC7\x52\x23\x59\x65\xFF\xF7\xFF\xFF\xFF\xF7\xDA\x8D\x94\x1B\xB4\x13\x17\x5D\xFF\xE7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xEF\xF8\x54\xB5\x13\x17\x14\x17\x14\x94\x1B\xBE\x9E\xFF\xF7\xFF\xFF\xFF\xFF\x5F\xCF\x13\x4C\xBF\x86\x77\x24\xB4\x0B\x96\x54\xFF\xE7\xFF\xE7\x12\x5C\x92\x33\xB3\x2B\xD4\x33\xD3\x2B\xD3\x23\x91\x2B\x9C\xB6\xFF\xF7\xFF\xE7\x55\x4C\xD4\x13\x16\x0C\x16\x0C\xD4\x1B\x3F\xC7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xB4\x74\x71\x33\xD3\x33\xF4\x3B\xD3\x33\xD3\x33\xB3\x33\xD4\x3B\xF4\x3B\xD3\x3B\xD3\x3B\xF3\x3B\xD3\x3B\xB2\x3B\x13\x44\xD2\x33\xD2\x33\x14\x2C\xB3\x2B\xDD\xBE\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\x18\x6D\xB5\x13\xB5\x0B\x59\x5D\x7F\xB7\x3F\xBF\x7F\xCF\x7F\xC7\xBF\x96\x16\x1C\x17\x0C\xD4\x1B\x5D\x86\x5F\xBF\x7F\xC7\x7F\xC7\x5F\xAF\xDC\x6D\xD5\x13\xB5\x0B\xB8\x44\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xBD\xBE\x59\x7D\xBB\x75\x9B\x6D\xDC\x75\xBB\x75\xDB\x6D\xDB\x6D\xDA\x75\xDB\x75\xFC\x6D\x77\x2C\xF5\x13\xF5\x13\xF9\x44\xDC\x6D\xBB\x75\xBB\x75\xBC\x75\xBC\x75\xBB\x75\xBB\x75\xBB\x75\xBA\x75\xF9\x8D\xFF\xDF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xBF\x55\x3C\x17\x1C\xB6\x13\x35\x3C\xFF\xD7\xFF\xFF\xFF\xFF\xFF\xF7\xB8\x9D\xBC\xC6\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\x33\x5C\x5F\xBF\xFF\xF7\xFF\xFF\xFF\xE7\xF6\x6C\xF4\x23\x93\x1B\x1E\xAF\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\x3F\xB7\x94\x23\x17\x1C\x17\x14\xB4\x13\x1C\x86\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xBF\xDF\xFF\xC7\x35\x24\xB4\x0B\x96\x54\xFF\xE7\xFF\xE7\x34\x4C\x93\x1B\x15\x24\xD4\x23\xB3\x1B\x15\x14\xB3\x1B\x9D\xAE\xFF\xF7\xFF\xF7\x58\x7D\xB4\x1B\x36\x14\xF5\x0B\x76\x3C\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\x53\x64\x51\x2B\x93\x23\x72\x23\x72\x2B\x92\x23\x92\x23\x52\x23\x72\x2B\x52\x2B\x52\x2B\x52\x23\x72\x23\x52\x2B\x51\x23\x92\x23\xF4\x23\xD6\x13\x94\x1B\xDE\xB6\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\x39\x6D\xD5\x13\x37\x0C\x15\x14\xF5\x1B\xD4\x1B\xD5\x1B\xF5\x1B\x16\x14\x17\x14\x17\x14\xF7\x13\x17\x1C\xD5\x23\xB4\x1B\xD5\x1B\x16\x1C\x36\x14\x16\x0C\xD6\x0B\xB8\x4C\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xEF\xFF\xF7\xFF\xF7\xFF\xEF\xFF\xEF\xFF\xDF\xF9\x54\xB5\x13\xB4\x13\x1C\x86\xFF\xE7\xFF\xEF\xFF\xF7\xFF\xEF\xFF\xEF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xC7\x35\x3C\xD6\x13\xF7\x13\xD5\x1B\x1F\xA7\xFF\xF7\xFF\xFF\xFF\xFF\xDF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x3D\xCF\xFF\xE7\xFF\xFF\xFF\xFF\xDC\xBE\x1A\x8E\x35\x34\x96\x4C\xFF\xE7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\xF8\x64\xB5\x13\x17\x14\xB4\x13\xFB\x75\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xCF\x15\x24\xF5\x13\x76\x54\xFF\xDF\xFF\xD7\x34\x44\xB4\x1B\xD9\x3C\xBF\xAF\xFF\x8E\x16\x14\xB4\x0B\x1F\xA7\xFF\xE7\xFF\xEF\x9D\xAE\x93\x1B\x16\x14\xD4\x0B\xDB\x6D\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFE\xBE\xFF\x9E\x3F\x9F\x3F\x9F\x5F\xA7\x3F\x9F\x5F\x9F\x3F\x9F\x3F\x9F\x3F\xA7\x3F\xA7\x5F\xA7\x1F\x97\x5F\xA7\x3F\x9F\x3F\x97\x77\x2C\xF7\x0B\xB5\x13\xDE\xB6\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xEF\x18\x65\xB4\x13\x57\x14\x16\x0C\xD4\x0B\x16\x14\xD5\x0B\xD5\x0B\xF5\x0B\x16\x14\x16\x14\x38\x14\xD6\x0B\xD6\x13\xB5\x13\xD5\x13\xF5\x0B\xD5\x0B\xF5\x13\x94\x0B\x97\x4C\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xE7\xD8\x5C\xB5\x13\xB4\x13'
            b'\xBA\x85\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xC7\x15\x3C\xD5\x13\x17\x14\xB4\x0B\x9A\x6D\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xBF\xEF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xFF\xF7\xD8\x8D\xDD\x9E\x17\x6D\x5C\x9E\xFF\xF7\xFF\xFF\xFF\xF7\x7E\xDF\xFF\xFF\xFF\xFF\xFF\xF7\x5F\xBF\xB4\x1B\x16\x14\xD4\x13\xFB\x75\xFF\xF7\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xBF\xCF\x16\x24\xB5\x13\x97\x54\xFF\xDF\xFF\xD7\x35\x4C\x94\x1B\x1A\x55\xFF\xDF\xFF\xCF\xD5\x1B\xD6\x13\x5E\x76\x58\x6D\x3F\xBF\xFF\xDF\x36\x2C\xD5\x13\xD4\x1B\xBF\xBF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\x5F\xB7\x5F\xA7\x7F\xA7\x7F\xA7\x7F\xA7\x7F\xA7\x7F\xA7\x7F\xA7\x7F\xA7\x7F\xA7\x7F\xAF\x5F\xA7\x7F\xAF\x7F\xA7\xBF\x9F\x97\x2C\xF6\x03\xD5\x1B\xFE\xB6\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xEF\x18\x6D\x94\x13\x17\x14\x35\x24\xD7\x44\x95\x44\xB6\x4C\x95\x4C\x76\x3C\x15\x1C\x16\x14\xF6\x13\x77\x34\x97\x4C\x55\x4C\x96\x4C\xB6\x4C\x96\x4C\x96\x44\x97\x44\x96\x4C\xFF\xD7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xE7\xF7\x5C\xB5\x0B\xB5\x13\xDA\x85\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xD7\x55\x44\xF5\x1B\x16\x14\x16\x14\x56\x3C\xFF\xE7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x57\x8D\xFD\xBE\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\x5E\xCF\xD9\x8D\x9C\x9E\xFE\xBE\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xE7\xF1\x53\x5E\xD7\xFF\xF7\xFF\xFF\xFF\xE7\x18\x55\xB4\x13\xB3\x13\xDB\x75\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xD7\x16\x24\x95\x0B\xD7\x5C\xFF\xDF\xFF\xCF\xF4\x3B\x94\x1B\x7A\x65\xFF\xE7\x5F\xC7\xF5\x23\xD6\x13\xD5\x1B\x51\x1B\xFA\x85\x3F\xA7\xB4\x13\xF5\x13\xF5\x1B\x1F\x9F\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xBF\xEF\x51\x3B\x72\x2B\x72\x2B\x71\x2B\x71\x2B\x71\x2B\x71\x2B\x91\x2B\x92\x23\x92\x23\x72\x2B\x72\x2B\x72\x2B\x92\x2B\x72\x13\x15\x1C\x37\x14\x93\x13\xDE\xB6\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\xF7\x74\x52\x1B\x52\x13\x79\x6D\xFF\xD7\xFF\xE7\xFF\xE7\xFF\xE7\xBF\xBF\x14\x1C\x15\x14\xD4\x1B\xFF\x96\xFF\xDF\xFF\xEF\xFF\xE7\xFF\xE7\xFF\xE7\xFF\xDF\xFF\xCF\xF7\x54\xD3\x3B\xB9\x8D\x7E\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xE7\xF7\x5C\xD5\x13\xB4\x13\xDA\x85\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xB7\x54\xB5\x13\x17\x0C\x16\x14\xB3\x1B\xFE\xAE\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xE7\xD2\x3B\x79\x75\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\x3A\xA6\x1A\x96\x5B\xA6\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\x7E\x9E\x51\x23\x57\x75\xFF\xE7\xFF\xFF\xFF\xF7\x5F\xB7\xD3\x2B\xB3\x1B\xDB\x75\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xDF\x15\x24\xD5\x13\xB6\x54\xFF\xD7\xBF\xB7\xD2\x2B\x72\x13\x1B\x76\xFF\xE7\xB8\x85\xB3\x13\x16\x14\x73\x13\x97\x44\x9E\x86\x56\x2C\x15\x14\x36\x0C\xF6\x0B\x76\x34\xFF\xDF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xBF\xEF\xF2\x53\xB3\x3B\xD3\x3B\xD3\x3B\xD3\x3B\xD3\x3B\xD3\x3B\xF3\x3B\xF3\x3B\xF4\x3B\xF3\x3B\xD3\x3B\xF3\x3B\x14\x3C\x14\x2C\xD4\x1B\x16\x14\xD4\x23\xFE\xB6\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x9C\xC6\x1B\xA6\x3B\x9E\xFE\xBE\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xF7\xBF\xCF\x15\x24\x16\x14\xB3\x13\x3F\x9F\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xDF\x75\x44\xB4\x1B\x52\x1B\x5B\xAE\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xBF\xFF\xFF\xFF\xFF\xEF\xD6\x5C\xD4\x13\xD4\x13\xB9\x85\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xE7\x79\x75\xB4\x13\x37\x0C\x16\x0C\xB4\x13\x58\x6D\xFF\xE7\xFF\xFF\xFF\xFF\xFF\xF7\xFE\xB6\x93\x23\x35\x3C\xFF\xE7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xD7\x33\x54\x3B\x96\xFD\xBE\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\x77\x4C\x94\x23\x13\x44\xFF\xDF\xFF\xF7\xFF\xFF\xFF\xD7\xF4\x33\xB3\x1B\xDB\x75\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x9F\xD7\xF5\x23\xB4\x13\xB6\x4C\xFF\xD7'
            b'\x5C\x76\xB2\x1B\xD2\x23\xDD\x96\xFF\xE7\xF5\x6C\x71\x1B\xF5\x1B\x1E\x76\xFF\xB7\x19\x45\xB4\x13\xF4\x1B\x15\x1C\xD5\x03\xF5\x13\xB7\x5C\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\xFF\xD7\xFF\xCF\xFF\xCF\xFF\xCF\xFF\xCF\xFF\xCF\xFF\xCF\xFF\xCF\xFF\xC7\xFF\xC7\xFF\xC7\xFF\xC7\xFF\xCF\xFF\xC7\xFF\xB7\xB8\x34\xD5\x0B\xB4\x1B\xDE\xB6\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x9F\xCF\x14\x24\x15\x0C\xF4\x13\x9E\x86\xFF\xE7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xEF\x3F\xA7\xB3\x1B\xF6\x13\x94\x1B\x3F\xC7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xEF\xFF\xDF\x18\x55\xD4\x13\xB3\x13\xB9\x85\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\x9C\xA6\xB4\x13\x17\x0C\x37\x14\xD5\x1B\x14\x3C\xFF\xD7\xFF\xF7\xFF\xFF\xFF\xEF\x38\x75\x94\x13\x94\x1B\xDE\xAE\xFF\xF7\xFF\xFF\xFF\xF7\x9E\x96\x31\x23\x57\x75\xDF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xB6\x94\x1B\x94\x1B\x37\x6D\xFF\xEF\xFF\xFF\xFF\xF7\x3C\x86\xD3\x23\x93\x13\xDB\x75\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xD7\x15\x2C\xB4\x13\xD7\x4C\xFF\xBF\x56\x2C\xB4\x1B\xF3\x33\xFF\xCF\xFF\xEF\xFD\xC6\xD2\x4B\xFF\xA6\xFF\xBF\xB9\x44\xB5\x13\xB4\x13\xF7\x5C\x5F\xAF\x15\x24\xF5\x13\xB5\x1B\xB7\x4C\x7F\xCF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\xF9\x8D\x1B\x7E\x3D\x76\x3E\x76\x3E\x76\x3D\x76\x3D\x76\x3E\x76\x3E\x76\x3E\x76\x3E\x76\x5E\x76\x5E\x76\x5E\x76\x5E\x6E\x5F\x6E\x58\x24\x17\x0C\xB4\x13\xFE\xB6\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xE7\x55\x34\xF5\x0B\xF6\x13\x16\x24\xF9\x54\x3A\x65\x19\x55\x5A\x5D\x19\x5D\x39\x55\x35\x24\xF5\x13\xF6\x13\x77\x3C\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFB\x95\x1D\x86\x3C\x86\x3C\x7E\x3D\x76\x56\x2C\xF6\x13\x73\x13\xFB\x8D\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xD7\xD4\x23\xF6\x0B\x17\x14\xF5\x1B\x93\x1B\xFF\x9E\xFF\xEF\xFF\xEF\xFF\xD7\x55\x44\x95\x13\xD5\x13\x39\x65\xFF\xE7\xFF\xEF\xFF\xE7\x97\x4C\x93\x1B\xB6\x54\xFF\xE7\xFF\xF7\xFF\xF7\xFF\xE7\xD7\x64\x73\x13\xD4\x2B\x1F\xBF\xFF\xF7\xFF\xF7\xFF\xDF\x35\x34\xD4\x13\xB4\x13\xDB\x75\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x7F\xCF\x15\x2C\xB4\x13\xF7\x54\xBE\x96\x93\x1B\x73\x1B\x58\x75\xFF\xEF\xFF\xF7\xFF\xF7\x9F\xE7\xBF\xD7\xB3\x3B\x93\x23\xB4\x1B\x55\x44\x9F\xCF\xFF\xE7\x7D\x8E\x73\x1B\x94\x1B\x93\x23\x7B\xAE\xFF\xF7\xFF\xFF\xFF\xFF\xDF\xD7\x90\x3B\x50\x23\x92\x23\x73\x1B\x73\x23\x72\x23\x72\x23\x93\x1B\x93\x1B\x73\x23\x73\x23\x52\x1B\x72\x1B\x92\x1B\x93\x1B\x94\x13\xF6\x13\x37\x14\xB4\x13\xFD\xB6\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\x58\x65\x93\x13\x16\x1C\xF6\x1B\x95\x13\xB5\x1B\xB5\x13\xB5\x13\xB4\x13\xB4\x13\x15\x14\x36\x1C\x73\x13\xBB\x7D\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\x38\x6D\x52\x13\xD3\x1B\xB3\x13\xB4\x13\xF5\x1B\xF6\x1B\x73\x23\x7D\xAE\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\x39\x5D\xD5\x13\x16\x14\x37\x14\xB5\x13\x3A\x55\xFF\xDF\xFF\xDF\xDF\x8E\x73\x13\xF7\x1B\xF6\x1B\xF5\x2B\xFF\xB7\xFF\xDF\x5F\xAF\xD5\x1B\xF6\x13\xF4\x1B\x7F\xA7\xFF\xDF\xFF\xDF\x7F\xAF\xD3\x2B\xD4\x23\x96\x54\xFF\xF7\xFF\xFF\xFF\xEF\xFB\x8D\x94\x13\x17\x14\xD5\x1B\xDB\x75\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xBF\xDF\x74\x23\x74\x1B\x55\x54\xFF\xDF\xDB\x7D\x71\x3B\x7F\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\x79\x7D\x31\x2B\x54\x54\xBF\xD7\xFF\xF7\xFF\xF7\xFF\xE7\x99\x85\x51\x33\x1B\x96\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xE7\x12\x5C\xF2\x43\x14\x44\x14\x44\x14\x44\x14\x44\x14\x44\x34\x3C\x34\x44\x33\x44\x13\x44\x14\x4C\x14\x44\x34\x44\x34\x3C\x55\x3C\xB4\x1B\xD5\x0B\xB4\x1B\xBD\xB6\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xBF\xCF\x75\x54\x73\x23\xB4\x23'
            b'\x94\x1B\xB4\x1B\xB3\x1B\xB3\x13\xB4\x1B\x73\x13\xD4\x1B\x92\x23\xF6\x64\xFF\xE7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xBF\xCF\xB1\x2B\xB3\x13\xB4\x13\x94\x1B\x93\x23\x52\x23\xF7\x6C\xFF\xE7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\x1F\xAF\x94\x1B\xF6\x13\x17\x14\xF7\x0B\x37\x24\xB7\x44\x97\x4C\x56\x2C\xF6\x13\x17\x1C\xD6\x13\xD5\x13\x97\x34\xB6\x44\x35\x34\xD5\x13\x38\x14\xF6\x0B\x77\x2C\xB6\x44\xB6\x44\x56\x2C\xD4\x1B\x7D\x86\x9F\xC7\xFF\xF7\xFF\xFF\xDF\xD7\xF4\x3B\xD5\x13\x17\x14\x94\x13\xDC\x7D\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xBF\xE7\x19\x65\xD8\x5C\x78\x8D\xFF\xEF\xFF\xE7\x5F\xD7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xDF\xB9\x95\xDF\xE7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xBC\xBE\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xE7\xFF\xDF\xFF\xD7\xFF\xDF\xFF\xDF\xFF\xDF\xFF\xD7\xFF\xD7\xFF\xD7\xFF\xDF\xFF\xDF\xFF\xDF\xFF\xDF\xFF\xDF\xFF\xDF\xFF\xCF\x38\x6D\x97\x44\x55\x4C\x1E\xCF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xEF\x3F\xBF\x5D\x96\x7D\x96\x7D\x8E\x7C\x8E\x9D\x8E\x5D\x8E\x7D\x96\x9D\x96\x3F\xB7\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\xD9\x85\x38\x5D\x9A\x65\x9A\x75\x3C\x96\x1F\xBF\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\xD8\x64\xD4\x1B\x16\x0C\x37\x0C\x16\x0C\xD5\x13\xB5\x13\x16\x14\x37\x14\x17\x0C\x17\x14\x17\x14\xF6\x13\xD5\x13\xF6\x13\x17\x14\x17\x0C\x37\x0C\x16\x0C\xF4\x0B\xF4\x0B\x16\x0C\xF4\x1B\x5F\xB7\xFF\xF7\xFF\xFF\xFF\xF7\xFC\x85\x94\x1B\x16\x14\x16\x14\x95\x13\xDC\x7D\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xEF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xFF\xF7\xFF\xEF\xFF\xEF\xFF\xEF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xEF\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xBF\xCF\xD3\x2B\xD4\x13\x36\x0C\x37\x0C\x38\x14\x18\x14\x17\x0C\x17\x0C\x37\x0C\x37\x14\x37\x14\x17\x14\x17\x0C\x17\x0C\x37\x0C\x37\x0C\x37\x0C\x37\x0C\x36\x0C\x36\x04\x37\x04\xD4\x13\x3F\xBF\xFF\xFF\xFF\xF7\xFF\xEF\xFF\x9E\xD6\x1B\x36\x14\x36\x14\xB5\x13\xDC\x7D\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFE\xFF\xFF\xFF\xFF\xFF\xFF\xEF\xBE\xA6\xB2\x23\x16\x14\x16\x0C\x17\x0C\x17\x14\x37\x14\x37\x0C\x37\x04\x37\x0C\x37\x14\x16\x14\x17\x14\x17\x14\x37\x0C\x17\x0C'
            b'\x17\x0C\x17\x0C\x37\x0C\x36\x0C\x16\x0C\xB4\x23\x1F\xBF\xFF\xF7\xFF\xEF\x5F\xB7\x56\x34\xF5\x13\x36\x0C\x36\x0C\xB4\x13\xDB\x75\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xEF\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xEF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\x3B\x8E\x92\x1B\x16\x1C\x37\x1C\x17\x14\xF7\x0B\x37\x14\x57\x0C\x36\x04\x16\x0C\x17\x14\x17\x14\x17\x14\x37\x0C\x37\x0C\x18\x14\x17\x14\x17\x14\x17\x14\x17\x14\xB5\x23\x3F\xBF\xFF\xE7\xDE\x9E\xB2\x23\xF5\x1B\x57\x14\x37\x0C\x36\x14\xB4\x13\xDB\x75\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\x9A\xC6\xFF\xF7\xFF\xF7\x1A\xB6\xBF\xEF\xFF\xFF\xBA\xCE\xFF\xEF\xFF\xE7\x39\xAE\xFF\xF7\xFE\xD6\x3E\xD7\xFF\xF7\xFF\xF7\x5D\xD7\x5E\xD7\x5A\xB6\xB8\xA5\xD9\xAD\xD9\xAD\xFF\xEF\xDF\xDF\xD8\x9D\x97\x95\x1D\xCF\xFF\xF7\xBB\xCE\xBF\xEF\xFF\xFF\xBF\xEF\x9C\xCE\xFF\xFF\xFF\xFF\x5A\xB6\xBF\xDF\xFF\xFF\xDF\xEF\x39\xAE\xF9\x9D\xD9\x9D\xBC\xBE\xFF\xF7\xFC\xCE\xF9\x9D\xF9\x9D\x97\x95\x5E\xDF\xFF\xFF\xFF\xFF\x9E\xDF\xD7\x9D\x19\xA6\xD8\xA5\xDC\xCE\x7F\xE7\x1D\xD7\xFF\xF7\xFF\xFF\xFF\xFF\x59\xAE\x18\x9E\xB8\x95\x3A\xAE\xFF\xF7\xFF\xF7\x1A\xAE\x98\x95\x7B\xBE\xFF\xF7\x9B\xBE\xB8\xA5\xD9\xA5\xB8\x9D\x1D\xCF\xDC\xC6\xF9\xA5\xF9\xA5\x3A\xAE\xFF\xEF\xFF\xF7\xDF\xE7\xB9\xA5\x78\x9D\xDC\xC6\xFF\xF7\x9F\xDF\x9B\xBE\xFF\xFF\xFF\xFF\xFC\xCE\xDF\xE7\xFD\xCE\xBF\xE7\xFF\xF7\xBC\xC6\x98\x9D\xD9\xAD\xBF\xEF\xFF\xFF\x1E\xD7\x78\x9D\xD8\x9D\xBF\xE7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\x3B\x96\x72\x23\xD5\x13\x17\x14\x17\x14\xF7\x0B\x37\x0C\x37\x0C\x17\x0C\x38\x14\x17\x14\x37\x0C\x37\x0C\x37\x0C\x18\x14\x18\x14\x17\x0C\x17\x0C\x17\x14\xD5\x1B\x9F\xAF\x7E\x8E\xB3\x1B\xF4\x13\x16\x0C\xF6\x0B\x37\x0C\x17\x14\xB4\x13\xDB\x7D\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xF7\x15\x85\xDF\xD7\x9F\xCF\x91\x53\xDD\xC6\xFF\xF7\xB3\x7C\xFF\xEF\x9B\xA6\xF1\x53\x9F\xDF\xFD\xCE\xF5\x8C\xFF\xEF\xFF\xEF\x56\x85\xFD\xB6\xF5\x74\xFD\xC6\x1D\xCF\x3E\xD7\xFF\xEF\x36\x7D\x1E\xB7\x9F\xCF\x16\x85\xBF\xDF\x36\x8D\x9F\xDF\xFF\xEF\x3F\xC7\x77\x85\xFF\xF7\x9F\xDF\x33\x5C\xFA\x95\xFF\xF7\x5E\xDF\xB4\x74\x9F\xCF\x5F\xC7\xF6\x74\x5F\xC7\xB8\x95\xFA\x95\x7F\xCF\x1D\xCF\x9F\xEF\xFF\xFF\xFF\xFF\x3B\xA6\x77\x7D\x5E\xC7\x1D\xC7\x9F\xDF\x5B\xBE\x77\x9D\xFF\xF7\xFF\xFF\x7E\xDF\xD4\x74\x5F\xBF\x3E\xC7\x5E\xCF\xFF\xE7\x98\x95\xF9\xA5\x3E\xCF\x57\x95\x1A\xAE\x5F\xDF\x5A\xB6\x93\x6C\x1E\xBF\xDF\xD7\xF6\x7C\x7B\xB6\x5F\xCF\xFA\x95\x98\x85\xFF\xD7\xF5\x74\x9C\xBE\x3E\xD7\x15\x85\xDD\xB6\x5F\xBF\x4F\x43\x3E\xCF\xFF\xF7\x17\x8D\x7F\xD7\x77\x8D\x7F\xCF\xBD\xAE\x57\x85\x1E\xC7\x3A\xB6\x56\x9D\x7F\xDF\xD5\x74\xBF\xCF\xBD\xAE\x36\x8D\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\xDD\xA6\x14\x34\xB4\x1B\xD6\x13\x37\x1C\x17\x0C\xF7\x0B\x17\x0C\x17\x0C\x17\x0C\x37\x0C\x36\x04\x37\x0C\x18\x0C\x18\x0C\x17\x0C\x17\x0C\x17\x0C\x37\x1C\xD9\x44\x93\x1B\x15\x0C\x57\x0C\x57\x0C\x58\x14\x18\x0C\x17\x14\xB4\x13\xDB\x7D\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xF7\x19\x9E\xFD\xB6\xDD\xAE\xDA\x95\x1A\x9E\x7F\xCF\xD8\x9D\xFF\xE7\xB9\x85\x1E\xB7\x98\x8D\xFF\xEF\x36\x8D\xDF\xDF\xDF\xD7\x78\x85\xFF\xD7\x16\x75\xFD\xBE\x1D\xCF\x5E\xDF\xFF\xEF\xD9\x8D\xD9\x85\x1F\xB7\xFF\xD7\xFF\xE7\x36\x85\xF9\xA5\xDD\xB6\x1A\x8E\x78\x7D\xFF\xE7\x19\x9E\xFE\xAE\x98\x85\xFF\xEF\x7F\xD7\x17\x7D\x9F\xC7\xBF\xC7\x58\x7D'
            b'\x1E\xBF\xF9\x95\x1A\x96\x3E\xC7\x3D\xD7\xDF\xF7\xFF\xFF\xFF\xFF\x7C\xA6\x99\x7D\x3E\xBF\x3E\xC7\xFF\xE7\x7C\xBE\xB9\xA5\xFF\xF7\xFF\xFF\xBF\xE7\xF6\x74\x5F\xBF\x3E\xC7\x7F\xD7\xBF\xCF\xF5\x7C\xFF\xF7\xFF\xF7\xFF\xE7\xDF\xE7\xFF\xF7\xDF\xEF\x36\x85\xFF\xE7\xFF\xE7\x37\x85\xBD\xBE\x9F\xD7\x7C\x9E\x1A\x8E\xFD\xA6\xF9\x8D\xFF\xF7\xFF\xF7\xDF\xD7\x37\x75\x5F\xB7\x57\x75\x16\x7D\xFF\xE7\x79\x95\xBF\xD7\xD9\x8D\x1E\xB7\x98\x85\xBF\xCF\xFF\xEF\xFF\xF7\xBF\xE7\xBF\xDF\xF5\x74\x7C\x9E\x9F\xC7\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\x9F\xCF\x37\x6D\xB3\x23\xD5\x13\xF7\x0B\x38\x0C\x58\x14\x17\x0C\x37\x0C\x37\x0C\x37\x0C\x37\x0C\x38\x0C\x18\x0C\x17\x0C\x37\x0C\x37\x0C\x37\x14\xF5\x13\x16\x14\x37\x0C\x37\x04\x17\x04\x17\x0C\x17\x0C\x17\x14\xB4\x13\xDB\x75\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xF7\x1D\xBF\x1A\x9E\xDA\x95\xDF\xD7\xDA\x8D\xFA\x8D\x3F\xBF\x3F\xC7\xB5\x64\x1F\xB7\x54\x64\xFF\xDF\x5B\xA6\xBD\xB6\x5B\xAE\x9D\xAE\xFF\xE7\xD5\x74\xD8\x9D\xD8\xA5\x3A\xBE\xFF\xF7\xFF\xE7\xDD\xAE\x99\x85\x17\x75\xFF\xDF\x78\x8D\x98\x8D\x5B\xA6\xB9\x85\x99\x7D\xFF\xE7\xB4\x6C\xBD\xA6\xF6\x74\x7C\xAE\xFF\xDF\x95\x64\xFB\x8D\x34\x4C\x9D\x9E\xFF\xE7\xB8\x95\x37\x85\x1A\xA6\xD8\xA5\xBE\xEF\xFF\xFF\xFF\xF7\x9D\xAE\xB5\x64\x1A\x9E\xD8\x9D\x7F\xD7\xDC\xBE\xF9\xA5\xFF\xEF\xFF\xF7\xDF\xE7\x94\x6C\x1A\x96\xF9\xA5\xBC\xBE\x5E\xC7\x76\x8D\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\x9E\xE7\xF5\x84\xFF\xE7\xFF\xE7\x36\x85\x98\x8D\x17\x7D\xB5\x6C\xFF\xDF\x3B\x96\x7B\xA6\xFF\xFF\xFF\xFF\xFF\xE7\x58\x85\x9D\xA6\x7C\x9E\xDD\xAE\xD9\x8D\xFA\x95\xBF\xCF\xB9\x8D\x5F\xBF\x57\x7D\xFF\xDF\xFF\xF7\xFF\xFF\xFF\xF7\xFF\xEF\xFF\xE7\x1A\x9E\x37\x75\xB9\x95\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xEF\x3F\xAF\x59\x5D\x16\x2C\xB4\x13\x94\x13\xD5\x13\xD5\x13\xD5\x13\xF5\x13\xF5\x13\xF6\x13\xF6\x13\xF5\x13\xD5\x13\xF6\x13\xF5\x13\xD5\x13\xF5\x13\xF5\x0B\xF6\x0B\xF6\x13\xF6\x13\xF6\x13\xF5\x1B\x93\x1B\xBA\x7D\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xE7\xD5\x74\x78\x95\xFF\xEF\x1B\x96\x95\x64\xFF\xDF\xB9\x95\xD9\x95\x9D\xAE\x58\x85\x3B\x9E\xFF\xDF\x37\x8D\x57\x95\xFF\xE7\xFF\xE7\x16\x7D\xFF\xEF\xFF\xEF\xFF\xF7\xBF\xEF\x77\x95\xFF\xE7\xFF\xE7\x78\x85\x9D\xAE\x78\x8D\xBF\xDF\xFF\xEF\x9F\xCF\xB9\x8D\x1E\xB7\x16\x7D\xBC\xB6\x3A\xA6\x16\x85\x5F\xC7\x99\x85\xFF\xDF\x7F\xBF\xF6\x74\xFF\xDF\x97\x95\x5F\xCF\xFF\xE7\xFF\xEF\xFF\xF7\xFF\xFF\xFF\xFF\x5B\xA6\x5B\x9E\xFF\xEF\xFF\xEF\xFF\xEF\x7A\xB6\xD9\x9D\xFF\xEF\xFF\xF7\xDF\xDF\x36\x7D\xFF\xE7\xFF\xEF\xFF\xEF\xFF\xE7\xD4\x7C\x7E\xDF\xFF\xFF\xBB\xC6\x97\xA5\xFF\xFF\x9E\xE7\xF5\x84\xFF\xE7\xFF\xEF\x36\x85\xDF\xDF\xFF\xE7\x16\x7D\x1E\xBF\x7F\xC7\xF5\x7C\xFF\xF7\xFF\xFF\x5B\xB6\xB8\x95\xFE\xBE\xFA\x95\xFF\xE7\x97\x8D\xF1\x53\xFF\xD7\x98\x8D\x7F\xC7\xD9\x95\x7B\xAE\xFF\xF7\xDF\xEF\x35\x95\xBC\xC6\xF9\xA5\xFF\xEF\xFF\xE7\xB4\x74\x9F\xEF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xEF\x9F\xD7\x9D\xAE\x79\x7D\xB6\x5C\x35\x44\x15\x3C\xF4\x3B\x14\x34\x34\x34\x34\x34\x14\x34\x14\x34\x15\x34\x15\x34\x14\x34\x14\x34\x14\x34\x15\x34\x15\x34\x15\x34\x35\x3C\xF4\x3B\xB2\x33\xDA\x95\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\x56\x95\x3A\xBE\xFF\xF7\xFD\xBE\x36\x7D\xFF\xEF\x56\x95\xFF\xF7\xFF\xF7\xBF\xDF\x56\x8D\xFF\xEF\x76\x95\xB8\xAD\xFF\xF7\xFF\xEF\xF5\x84\x77\x8D\x98\x8D\x57\x95\xBF\xDF\x5A\xAE\x15\x85\x97\x8D\x97\x8D\xFF\xE7\x77\x9D\x7F\xDF\xFF\xF7\x3E\xD7\xF9\xA5\xD9\x9D\x3E\xCF\xFF\xF7\xFF\xFF\x77\x95\x7C\xB6\xD9\x9D\xFF\xEF\xFF\xEF\xD8\x9D\x7B\xB6\x3A\xAE\xD6\x74\xB9\x8D\x77\x85\xBB\xBE\xFF\xFF\xFF\xFF\xDC\xBE\xD5\x74\x98\x8D\x77\x95\x3A\xB6\x1E\xCF\xB5\x74\x98\x8D\x77\x9D\x7F\xD7\xF6\x7C\x98\x85\x78\x8D\x98\x95\xFF\xE7\xFD\xCE\xF5\x8C\x77\x9D\xF5\x8C\x3D\xD7\xFF\xFF\x9E\xE7\x77\x9D\xFF\xEF\xFF\xF7\x97\x9D\x7F\xE7\xFF\xF7\x5E\xD7\x14\x85\xFF\xF7\x5A\xAE\x37\x85\x98\x95\x36\x8D\xFF\xE7\xFD\xC6\x39\xAE\xFF\xF7\xBF\xE7\x53\x6C\xDF\xDF\xF9\xA5\x5E\xCF\xDF\xDF\x56\x8D\x97\x8D\x35\x85\x7A\xBE\xFF\xEF\x57\x8D\x78\x8D\x57\x85\x19\xA6'
            b'\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\xFF\xE7\xFF\xDF\xFF\xD7\xDF\xD7\xFF\xD7\xFF\xCF\xFF\xCF\xFF\xCF\xFF\xD7\xFF\xCF\xFF\xCF\xFF\xCF\xFF\xD7\xFF\xD7\xFF\xD7\xFF\xD7\xFF\xD7\xBF\xCF\xFF\xD7\xBF\xD7\xFF\xE7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xEF\xFF\xEF\xFF\xF7\xDF\xF7\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xEF\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xEF\x9F\xD7\xDF\xDF\xBF\xE7\xFF\xF7\xFF\xEF\xDF\xDF\x7E\xD7\xFF\xEF\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xEF\xFF\xEF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xEF\xFF\xEF\xFF\xF7\xFF\xFF\xFF\xFF\xDF\xEF\xFF\xF7\xBF\xE7\xBF\xD7\xDF\xD7\xFF\xE7\xFF\xFF\xFF\xFF\xFF\xF7\xBF\xE7\xBF\xE7\xBF\xE7\xDF\xEF\xFF\xEF\xDF\xDF\xBF\xDF\xBF\xE7\xFF\xF7\xFF\xE7\xBF\xD7\xFF\xDF\x9F\xDF\xFF\xF7\xFF\xFF\xBF\xEF\x5E\xDF\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xEF\xFF\xF7\xFF\xF7\xDF\xDF\x7F\xD7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xEF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\x9F\xD7\xDF\xDF\xFF\xF7\xFF\xFF\xFF\xF7\x9F\xD7\x7F\xD7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xF7\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF'
            b'\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFE\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFE\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xDF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF'
        )

        waveshare_logo = lv.image_dsc_t(
            dict(
                header=dict(cf=lv.COLOR_FORMAT.RGB565, w=150, h=46),
                data_size=13800,
                data=waveshare_logo_data
            )
        )
               
        img = lv.image(self.tile1)
        img.set_src(waveshare_logo)
        img.align(lv.ALIGN.CENTER, 0, 0)

        lv.screen_load(self.scr)

        # Tile2: Show IMU data
        self.tile2 = self.tv.add_tile(0, 1, lv.DIR.TOP | lv.DIR.BOTTOM)
        table = lv.table(self.tile2)
        table.set_size(85, 265)
        table.align(lv.ALIGN.LEFT_MID, 15 ,0)
        table.remove_flag(lv.obj.FLAG.SCROLLABLE | lv.obj.FLAG.CLICKABLE)
        table.set_cell_value(0, 0, "ACC_X")
        table.set_cell_value(1, 0, "ACC_Y")
        table.set_cell_value(2, 0, "ACC_Z")
        table.set_cell_value(3, 0, "CYRO_X")
        table.set_cell_value(4, 0, "CYRO_Y")
        table.set_cell_value(5, 0, "CYRO_Z")
        table.set_style_bg_color(lv.palette_lighten(lv.PALETTE.BLUE, 1), lv.PART.ITEMS)
        table.add_style(style_imu_table, 0)

        self.table_imu_data = lv.table(self.tile2)
        self.table_imu_data.set_size(78, 265)
        self.table_imu_data.align(lv.ALIGN.CENTER, 15 ,0)
        self.table_imu_data.remove_flag(lv.obj.FLAG.SCROLLABLE | lv.obj.FLAG.CLICKABLE)
        self.table_imu_data.set_cell_value(0, 0, "0")
        self.table_imu_data.set_cell_value(1, 0, "0")
        self.table_imu_data.set_cell_value(2, 0, "0")
        self.table_imu_data.set_cell_value(3, 0, "0")
        self.table_imu_data.set_cell_value(4, 0, "0")
        self.table_imu_data.set_cell_value(5, 0, "0")
        self.table_imu_data.set_style_bg_color(lv.color_make(250, 144, 181), lv.PART.ITEMS)
        self.table_imu_data.add_style(style_imu_table, 0)

        table = lv.table(self.tile2)
        table.set_size(51, 265)
        table.align(lv.ALIGN.RIGHT_MID, -16 ,0)
        table.remove_flag(lv.obj.FLAG.SCROLLABLE | lv.obj.FLAG.CLICKABLE)
        table.set_cell_value(0, 0, "mg")
        table.set_cell_value(1, 0, "mg")
        table.set_cell_value(2, 0, "mg")
        table.set_cell_value(3, 0, "dps") 
        table.set_cell_value(4, 0, "dps")
        table.set_cell_value(5, 0, "dps")
        table.set_style_bg_color(lv.palette_lighten(lv.PALETTE.BLUE, 1), lv.PART.ITEMS)
        table.add_style(style_imu_table, 0)

        # Tile3: Show RTC data
        self.tile3 = self.tv.add_tile(0, 2, lv.DIR.TOP | lv.DIR.BOTTOM)
        table = lv.table(self.tile3)
        table.set_size(210, 43)
        table.set_column_width(0, 70);
        table.set_column_width(1, 70);
        table.set_column_width(2, 70);
        table.align(lv.ALIGN.CENTER, 0, -63)
        table.remove_flag(lv.obj.FLAG.SCROLLABLE | lv.obj.FLAG.CLICKABLE)
        table.set_cell_value(0, 0, "Year")
        table.set_cell_value(0, 1, "Mon")
        table.set_cell_value(0, 2, "Day")
        table.set_style_bg_color(lv.palette_lighten(lv.PALETTE.BLUE, 1), lv.PART.ITEMS)
        table.add_style(style_rtc_table, 0)

        self.table_rtc_date = lv.table(self.tile3)
        self.table_rtc_date.set_size(210, 43)
        self.table_rtc_date.set_column_width(0, 70);
        self.table_rtc_date.set_column_width(1, 70);
        self.table_rtc_date.set_column_width(2, 70);
        self.table_rtc_date.align(lv.ALIGN.CENTER, 0, -21)
        self.table_rtc_date.remove_flag(lv.obj.FLAG.SCROLLABLE | lv.obj.FLAG.CLICKABLE)
        self.table_rtc_date.set_cell_value(0, 0, "0")
        self.table_rtc_date.set_cell_value(0, 1, "0")
        self.table_rtc_date.set_cell_value(0, 2, "0")
        self.table_rtc_date.set_style_bg_color(lv.color_make(250, 144, 181), lv.PART.ITEMS)
        self.table_rtc_date.add_style(style_rtc_table, 0)

        table = lv.table(self.tile3)
        table.set_size(210, 43)
        table.set_column_width(0, 70);
        table.set_column_width(1, 70);
        table.set_column_width(2, 70);
        table.align(lv.ALIGN.CENTER, 0, 21)
        table.remove_flag(lv.obj.FLAG.SCROLLABLE | lv.obj.FLAG.CLICKABLE)
        table.set_cell_value(0, 0, "Hour")
        table.set_cell_value(0, 1, "Min")
        table.set_cell_value(0, 2, "Sec")
        table.set_style_bg_color(lv.palette_lighten(lv.PALETTE.BLUE, 1), lv.PART.ITEMS)
        table.add_style(style_rtc_table, 0)

        self.table_rtc_time = lv.table(self.tile3)
        self.table_rtc_time.set_size(210, 43)
        self.table_rtc_time.set_column_width(0, 70);
        self.table_rtc_time.set_column_width(1, 70);
        self.table_rtc_time.set_column_width(2, 70);
        self.table_rtc_time.align(lv.ALIGN.CENTER, 0, 63)
        self.table_rtc_time.remove_flag(lv.obj.FLAG.SCROLLABLE | lv.obj.FLAG.CLICKABLE)
        self.table_rtc_time.set_cell_value(0, 0, "0")
        self.table_rtc_time.set_cell_value(0, 1, "0")
        self.table_rtc_time.set_cell_value(0, 2, "0")
        self.table_rtc_time.set_style_bg_color(lv.color_make(250, 144, 181), lv.PART.ITEMS)
        self.table_rtc_time.add_style(style_rtc_table, 0)

        # Tile4: Some widgets
        self.tile4 = self.tv.add_tile(0, 3, lv.DIR.TOP)
        tabview = lv.tabview(self.tile4);
        tab1 = tabview.add_tab("BEEP");
        tab2 = tabview.add_tab("LCD BL");

        self.sw = lv.switch(tab1);
        self.sw.set_size(70, 40)
        self.sw.align(lv.ALIGN.CENTER, -45, 0)
        self.sw.add_style(style_sw, lv.STATE.CHECKED | lv.PART.INDICATOR)
        self.sw.add_event_cb(self.sw_event_cb, lv.EVENT.VALUE_CHANGED, None)

        self.slider = lv.slider(tab1);
        self.slider.set_size(10, 100)
        self.slider.align(lv.ALIGN.CENTER, 45, 0)
        self.slider.add_style(style_indic, lv.PART.INDICATOR)
        self.slider.add_style(style_indic_pr, lv.PART.INDICATOR | lv.STATE.PRESSED)
        self.slider.add_style(style_slider, lv.PART.KNOB)
        self.slider.add_event_cb(self.slider_event_cb, lv.EVENT.VALUE_CHANGED, None)

        self.roller = lv.roller(tab2)
        opt = ["1", "2", "3", "4", "5", "6", "7", "8", "9", "10"]
        self.roller.set_options("\n".join(opt), lv.roller.MODE.NORMAL)
        self.roller.set_visible_row_count(3)
        self.roller.align(lv.ALIGN.CENTER, 0, 0)
        self.roller.set_selected(5, lv.ANIM.OFF)
        self.roller.add_style(style_roller, 0)
        self.roller.add_event_cb(self.roller_event_cb, lv.EVENT.VALUE_CHANGED, None)

        # data update
        self.imu_data_update()
        self.rtc_data_update()
        
    # Check update
    def update_check(self,tilex):
        ret = True

        active_tile = self.tv.get_tile_active() 
        if active_tile != tilex:
            ret = False

        if self.TSC.Gestures != 0x00 and self.TSC.Gestures != 0x05:  # touch the screen but don't click
            self.TSC.Gestures = 0x00 
            ret = False

        return ret

    # Data update
    def imu_data_update(self):
        # Read QMI8658
        xyz = self.IMU.Read_XYZ()  
        
        for i in range(6):
            table_text = "{:4.1f}".format(xyz[i])
            self.table_imu_data.set_cell_value(i, 0, table_text)
            
    def rtc_data_update(self):
        # Read PCF85063
        data = self.RTC.readTime()

        table_text = "{:02d}".format(data[2])  
        self.table_rtc_time.set_cell_value(0, 0, table_text)

        table_text = "{:02d}".format(data[1])  
        self.table_rtc_time.set_cell_value(0, 1, table_text)

        table_text = "{:02d}".format(data[0])  
        self.table_rtc_time.set_cell_value(0, 2, table_text)
        

        table_text = "{:d}".format(data[6])  
        self.table_rtc_date.set_cell_value(0, 0, table_text)

        table_text = "{:02d}".format(data[5])  
        self.table_rtc_date.set_cell_value(0, 1, table_text)

        table_text = "{:02d}".format(data[3])  
        self.table_rtc_date.set_cell_value(0, 2, table_text)
        
    # Timer callback
    def imu_data_update_timer_cb(self,t):
        # Check update
        if self.update_check(self.tile2) == True:
            # Update data
            self.imu_data_update()
        
        return
    
        
    def rtc_data_update_timer_cb(self,t):
        # Check update
        if self.update_check(self.tile3) == True:    
            # Update data
            self.rtc_data_update()
            
        return

    # Event callback
    def sw_event_cb(self,event):
        if self.sw.has_state(lv.STATE.CHECKED):
            self.BEEP_pwm.duty_u16(65535 // 2)
        else:
            self.BEEP_pwm.duty_u16(0)
            
    def slider_event_cb(self,event):
        value = self.slider.get_value()
        self.BEEP_pwm.freq(1000 + value * 10)
        
    def roller_event_cb(self,event):
        value = self.roller.get_selected() + 1
        self.LCD.set_bl_pwm(65535 * value * 10 // 100)


